<?php
/***************************************************************
* Copyright notice
*
* (c) 2008-2009 Niels Pardon (mail@niels-pardon.de)
* All rights reserved
*
* This script is part of the TYPO3 project. The TYPO3 project is
* free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* The GNU General Public License can be found at
* http://www.gnu.org/copyleft/gpl.html.
*
* This script is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

require_once(PATH_tslib . 'class.tslib_content.php');
require_once(PATH_tslib . 'class.tslib_feuserauth.php');
require_once(PATH_t3lib . 'class.t3lib_timetrack.php');

require_once(t3lib_extMgm::extPath('seminars') . 'lib/tx_seminars_constants.php');
require_once(t3lib_extMgm::extPath('seminars') . 'tests/fixtures/class.tx_seminars_eventEditorChild.php');
require_once(t3lib_extMgm::extPath('seminars') . 'pi1/class.tx_seminars_pi1.php');

require_once(t3lib_extMgm::extPath('oelib') . 'class.tx_oelib_testingFramework.php');

/**
 * Testcase for the eventEditorChild class in the 'seminars' extensions.
 *
 * @package		TYPO3
 * @subpackage	tx_seminars
 *
 * @author		Niels Pardon <mail@niels-pardon.de>
 */
class tx_seminars_eventEditorChild_testcase extends tx_phpunit_testcase {
	private $fixture;

	/** our instance of the testing framework */
	private $testingFramework;

	/** the UID of a dummy front end page */
	private $frontEndPageUid;

	/** the instance of tx_seminars_pi1*/
	private $pi1;

	public function setUp() {
 		$this->testingFramework = new tx_oelib_testingFramework('tx_seminars');
		$this->frontEndPageUid = $this->testingFramework->createFrontEndPage();
		$this->testingFramework->createFakeFrontEnd($this->frontEndPageUid);

		$this->pi1 = new tx_seminars_pi1();
		$this->pi1->init(
			array(
				'isStaticTemplateLoaded' => 1,
				'eventSuccessfullySavedPID' => $this->frontEndPageUid,
			)
		);

		$this->fixture = new tx_seminars_eventEditorChild($this->pi1);
	}

	public function tearDown() {
		$this->testingFramework->cleanUp();
		unset($this->testingFramework, $this->fixture, $this->pi1);
	}


	///////////////////////////////////////////////////////
	// Tests for getting the event-successfully-saved URL
	///////////////////////////////////////////////////////

	public function testGetEventSuccessfullySavedUrlReturnsUrlStartingWithHttp() {
		$this->assertRegExp(
			'/^http:\/\/./',
			$this->fixture->getEventSuccessfullySavedUrl()
		);
	}


	////////////////////////////////////////////
	// Tests concerning populateListCategories
	////////////////////////////////////////////

	public function testPopulateListCategoriesDoesNotCrash() {
		$this->fixture->populateListCategories(array());
	}


	////////////////////////////////////////
	// Tests concerning hasAccess function
	////////////////////////////////////////

	public function testHasAccessForLoggedOutUserReturnsFalse() {
		$this->testingFramework->logoutFrontEndUser();

		$this->assertFalse(
			$this->fixture->hasAccess()
		);
	}

	public function testHasAccessForLoggedInUserInUnauthorizedUsergroupReturnsFalse() {
		$this->testingFramework->createAndLoginFrontEndUser(
			$this->testingFramework->createFrontEndUsergroup()
		);

		$this->assertFalse(
			$this->fixture->hasAccess()
		);
	}

	public function testHasAccessForLoggedInUserInAuthorizedUsergroupAndNoUidSetReturnsTrue() {
		$groupUid = $this->testingFramework->createFrontEndUsergroup(
			array('title' => 'test')
		);
		$this->testingFramework->createAndLoginFrontEndUser($groupUid);

		$this->pi1->setConfigurationValue('eventEditorFeGroupID', $groupUid);

		$this->assertTrue(
			$this->fixture->hasAccess()
		);
	}

	public function testHasAccessForLoggedInUserInAuthorizedUsergroupButNotAuthorOfGivenEventReturnsFalse() {
		$groupUid = $this->testingFramework->createFrontEndUsergroup(
			array('title' => 'test')
		);
		$this->testingFramework->createAndLoginFrontEndUser($groupUid);

		$this->pi1->setConfigurationValue('eventEditorFeGroupID', $groupUid);
		$this->pi1->piVars['seminar'] = $this->testingFramework->createRecord(
			SEMINARS_TABLE_SEMINARS, array()
		);
		$this->pi1->piVars['action'] = 'EDIT';

		$this->assertFalse(
			$this->fixture->hasAccess()
		);
	}

	public function testHasAccessForLoggedInUserInAuthorizedUsergroupAndAuthorOfGivenEventReturnsTrue() {
		$groupUid = $this->testingFramework->createFrontEndUsergroup(
			array('title' => 'test')
		);
		$userUid = $this->testingFramework->createAndLoginFrontEndUser($groupUid);

		$this->pi1->setConfigurationValue('eventEditorFeGroupID', $groupUid);
		$this->pi1->piVars['seminar'] = $this->testingFramework->createRecord(
			SEMINARS_TABLE_SEMINARS, array('owner_feuser' => $userUid)
		);
		$this->pi1->piVars['action'] = 'EDIT';

		$this->assertTrue(
			$this->fixture->hasAccess()
		);
	}

	public function testHasAccessForLoggedInUserAndInvalidSeminarIdReturnsFalse() {
		$groupUid = $this->testingFramework->createFrontEndUsergroup(
			array('title' => 'test')
		);
		$userUid = $this->testingFramework->createAndLoginFrontEndUser($groupUid);

		$this->pi1->setConfigurationValue('eventEditorFeGroupID', $groupUid);
		$this->pi1->piVars['seminar']
			= $this->testingFramework->getAutoIncrement(
				SEMINARS_TABLE_SEMINARS
			);
		$this->pi1->piVars['action'] = 'EDIT';

		$this->assertFalse(
			$this->fixture->hasAccess()
		);
	}
}
?>